@@ -18,7 +18,7 @@ from .spl_base_command import SplBaseCommand
 
 
 class SplStreamingBatchCommand(SplBaseCommand):
-    def process_data(self, argv=None, input_stream=sys.stdin.buffer, output_stream=sys.stdout.buffer):
+    def process_data(self, argv=None, input_stream=sys.stdin.buffer, output_stream=sys.__stdout__.buffer):
         while True:
             execute_meta = self.process_protocol_execute(input_stream)
             resp = self.streaming_handle(self.lines)
